==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sk.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendár",
    "%s has published the calendar \"%s\"" : "%s zverejnil kalendár \"%s\"",
    "Too many redirects. Aborting ..." : "Príliš veľa presmerovaní. Ruším ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdialený server neposkytol prístup ku kalendáru (HTTP chyba {%s})",
    "Error connecting to remote server" : "Chyba pri pripájaní na vzdialený server",
    "Error requesting resource on remote server" : "Chyba pri vyžadovaní zdroja zo vzdialeného servera",
    "Individual" : "Individuálny",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Miestnosť",
    "Unknown" : "Neznámy",
    "Required" : "Vyžadovaný",
    "Optional" : "Voliteľný",
    "Does not attend" : "Nezúčastní sa",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ste v neznámej časovej zóne ({tz}), používa sa UTC",
    "Please create a calendar first." : "Prosím, najskôr vytvorte kalendár",
    "New event" : "Nová udalosť",
    "CalDAV address for clients" : "CalDAV adresa pre klientov",
    "Error saving WebCal-calendar" : "Chyba pri ukladaní WebCal-kalendára",
    "WebDAV address for subscriptions" : "WebDAV adresa pre odbery",
    "EMail has been sent." : "E-mail bol odoslaný.",
    "There was an issue while sending your EMail." : "Počas odosielania e-mailu nastal problém.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Reminders" : "Pripomienky",
    "Repeating" : "Opakovanie",
    "When shared show full event" : "Zobraziť úplnú udalosť, ak je sprístupnená",
    "When shared show only busy" : "Zobraziť zaneprázdnený, ak je udalosť sprístupnená",
    "When shared hide this event" : "Skryť udalosť, ak je sprístupnená",
    "Confirmed" : "Potvrdené",
    "Tentative" : "Neistý",
    "Cancelled" : "Zrušené",
    "Please add a title!" : "Prosím pridajte názov!",
    "Please select a calendar!" : "Prosím vyberte kalendár",
    "Global" : "Globálny",
    "None" : "Žiadny",
    "Every day" : "Každý deň",
    "Every week" : "Každý týždeň",
    "Every month" : "Každý mesiac",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Čo tak začat importovaním nejakých kalendárov?",
    "At time of event" : "Pridajte čas udalosti",
    "5 minutes before" : "5 minút pred",
    "10 minutes before" : "10 minút pred",
    "15 minutes before" : "15 minút pred",
    "30 minutes before" : "30 minút pred",
    "1 hour before" : "1 hodinu pred",
    "2 hours before" : "2 hodiny pred",
    "Custom" : "Vlastný",
    "Audio" : "Zvuk",
    "E Mail" : "E-mail",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodín",
    "days" : "dni",
    "week" : "týždeň",
    "before" : "pred",
    "start" : "začiatok",
    "end" : "koniec",
    "Editing reminders of unknown type not supported." : "Editovanie pripomienky neznámeho typu nie je podporované.",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Successfully imported" : "Úspešne importovaný",
    "Partially imported, 1 failure" : "Čiastočne importovaný, 1 chyba",
    "Partially imported, {n} failures" : "Čiastočne importovaný, {n} chýb",
    "Audio alarm" : "Zvukový alarm",
    "E-Mail" : "email",
    "{type} {time} before the event starts" : "{type} {time} pred začiatkom udalosti",
    "{type} {time} before the event ends" : "{type} {time} pred koncom udalosti",
    "{type} {time} after the event starts" : "{type} {time} po začiatku udalosti",
    "{type} {time} after the event ends" : "{type} {time} po ukončení udalosti",
    "{type} at the event's start" : "{type} pri začiatku udalosti",
    "{type} at the event's end" : "{type} pri skončení udalosti",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
    "Please enter a valid WebCal-URL" : "Zadajte prosím platnú WebCal-URL",
    "Title of the Event" : "Názov udalosti",
    "starts" : "začína",
    "ends" : "končí",
    "All day Event" : "Celodenná udalosť",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "More ..." : "Viac ...",
    "Create" : "Vytvoriť",
    "Update" : "Aktualizovať",
    "Close" : "Zavrieť",
    "Location" : "Umiestnenie",
    "Description" : "Popis",
    "Event status" : "Stav udalosti",
    "Visibility when sharing" : "Viditelnosť pri sprístupnení",
    "Export" : "Export",
    "%s has published the calendar %s" : "%s zverejnil kalendár %s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chceme vás informovať, že %s zverejnil kalendár {boldstart}%s{boldend}.",
    "Click here to access it" : "Pre zobrazenie kliknite sem",
    "Cheers!" : "Pekný deň!",
    "We wanted to inform you that %s has published the calendar %s." : "Chceme vás informovať, že %s zverejnil kalendár %s.",
    "Click on the link below to access it" : "Pre zobrazenie kliknite na odkaz nižšie",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "Today" : "Dnes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektoré udalosti v tomto kalendári sú poškodené. Pre viac informácií skontrolujte prosím JS konzolu.",
    "Share Calendar" : "Sprístupniť kalendár",
    "Shared" : "Sprístupnené",
    "More" : "Viac",
    "Edit" : "Upraviť",
    "Link" : "Odkaz",
    "iCal link" : "iCal odkaz",
    "Download" : "Sťahovanie",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "can edit" : "môže upraviť",
    "Share link" : "Sprístupniť odkaz",
    "Public access" : "Verejný prístup",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "New Calendar" : "Nový kalendár",
    "Name" : "Názov",
    "New Subscription" : "Nový odber",
    "Go back" : "Ísť späť",
    "Go forward" : "Ísť dopredu",
    "Edit event" : "Upraviť udalosť",
    "Delete Event" : "Zmazať udalosť",
    "Save Event" : "Uložiť udalosť",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relatívny",
    "Absolute" : "Absolútny",
    "Repeat" : "Opakovať",
    "Add" : "Pridať",
    "E-Mail address of attendee" : "E-mail adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Pre pridávanie účastníkov priraďte k vašemu účtu e-mailovú adresu v osobných nastaveniach.",
    "from" : "od",
    "to" : "do",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pre rozšírené pravidlá bude pridaná v ďalších aktualizáciách.",
    "Repeat every ..." : "Opakovať každý ...",
    "end repeat ..." : "ukončiť opakovanie ...",
    "times" : "krát",
    "Import Calendars" : "Importovať kalendáre",
    "Import canceled" : "Import zrušený",
    "Analyzing calendar" : "Analyzujem kalendár",
    "New calendar" : "Nový kalendár",
    "File is empty" : "Súbor je prázdny",
    "Import scheduled" : "Import naplánovaný",
    "Publish URL" : "Zverejniť URL",
    "Settings & import" : "Nastavenia a import",
    "Skip simple event editor" : "Nepoužívať jednoduchý editor",
    "Show week numbers" : "Zobraziť čísla týždňov",
    "Import calendar" : "Importovať kalendár",
    "No Calendars selected for import" : "Nebol označený kalendár na import",
    "Primary CalDAV address" : "Primárna CalDAV adresa",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sk.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendár",
    "%s has published the calendar \"%s\"" : "%s zverejnil kalendár \"%s\"",
    "Too many redirects. Aborting ..." : "Príliš veľa presmerovaní. Ruším ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdialený server neposkytol prístup ku kalendáru (HTTP chyba {%s})",
    "Error connecting to remote server" : "Chyba pri pripájaní na vzdialený server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Chyba pri vyžiadaní zdrojov zo vzdialeného servera. To može súvisieť s nesprávnym certifikátom.",
    "Error requesting resource on remote server" : "Chyba pri vyžadovaní zdroja zo vzdialeného servera",
    "Individual" : "Individuálny",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Miestnosť",
    "Unknown" : "Neznámy",
    "Required" : "Vyžadovaný",
    "Optional" : "Voliteľný",
    "Does not attend" : "Nezúčastní sa",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ste v neznámej časovej zóne ({tz}), používa sa UTC",
    "Please create a calendar first." : "Prosím, najskôr vytvorte kalendár",
    "New event" : "Nová udalosť",
    "CalDAV address for clients" : "CalDAV adresa pre klientov",
    "Error saving WebCal-calendar" : "Chyba pri ukladaní WebCal-kalendára",
    "WebDAV address for subscriptions" : "WebDAV adresa pre odbery",
    "EMail has been sent." : "E-mail bol odoslaný.",
    "There was an issue while sending your EMail." : "Počas odosielania e-mailu nastal problém.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Reminders" : "Pripomienky",
    "Repeating" : "Opakovanie",
    "When shared show full event" : "Zobraziť úplnú udalosť, ak je sprístupnená",
    "When shared show only busy" : "Zobraziť zaneprázdnený, ak je udalosť sprístupnená",
    "When shared hide this event" : "Skryť udalosť, ak je sprístupnená",
    "Confirmed" : "Potvrdené",
    "Tentative" : "Neistý",
    "Cancelled" : "Zrušené",
    "Please add a title!" : "Prosím pridajte názov!",
    "Please select a calendar!" : "Prosím vyberte kalendár",
    "The event ends before it starts!" : "Udalosť končí skôr ako začne!",
    "Global" : "Globálny",
    "None" : "Žiadny",
    "Every day" : "Každý deň",
    "Every week" : "Každý týždeň",
    "Every month" : "Každý mesiac",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Čo tak začat importovaním nejakých kalendárov?",
    "At time of event" : "Pridajte čas udalosti",
    "5 minutes before" : "5 minút pred",
    "10 minutes before" : "10 minút pred",
    "15 minutes before" : "15 minút pred",
    "30 minutes before" : "30 minút pred",
    "1 hour before" : "1 hodinu pred",
    "2 hours before" : "2 hodiny pred",
    "Custom" : "Vlastný",
    "Audio" : "Zvuk",
    "E Mail" : "E-mail",
    "Pop up" : "Vyskakovacie okno",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodín",
    "days" : "dni",
    "week" : "týždeň",
    "before" : "pred",
    "start" : "začiatok",
    "end" : "koniec",
    "Editing reminders of unknown type not supported." : "Editovanie pripomienky neznámeho typu nie je podporované.",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Successfully imported" : "Úspešne importovaný",
    "Partially imported, 1 failure" : "Čiastočne importovaný, 1 chyba",
    "Partially imported, {n} failures" : "Čiastočne importovaný, {n} chýb",
    "Audio alarm" : "Zvukový alarm",
    "Pop-up" : "Vyskakovanie okno",
    "E-Mail" : "email",
    "{type} {time} before the event starts" : "{type} {time} pred začiatkom udalosti",
    "{type} {time} before the event ends" : "{type} {time} pred koncom udalosti",
    "{type} {time} after the event starts" : "{type} {time} po začiatku udalosti",
    "{type} {time} after the event ends" : "{type} {time} po ukončení udalosti",
    "{type} at the event's start" : "{type} pri začiatku udalosti",
    "{type} at the event's end" : "{type} pri skončení udalosti",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
    "Please enter a valid WebCal-URL" : "Zadajte prosím platnú WebCal-URL",
    "Title of the Event" : "Názov udalosti",
    "Starts" : "Začína",
    "Ends" : "Končí",
    "All day Event" : "Celodenná udalosť",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "More ..." : "Viac ...",
    "Create" : "Vytvoriť",
    "Update" : "Aktualizovať",
    "Close" : "Zavrieť",
    "Location" : "Umiestnenie",
    "Description" : "Popis",
    "Event status" : "Stav udalosti",
    "Visibility when sharing" : "Viditelnosť pri sprístupnení",
    "Export" : "Export",
    "%s has published the calendar %s" : "%s zverejnil kalendár %s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chceme vás informovať, že %s zverejnil kalendár {boldstart}%s{boldend}.",
    "Click here to access it" : "Pre zobrazenie kliknite sem",
    "Cheers!" : "Pekný deň!",
    "We wanted to inform you that %s has published the calendar %s." : "Chceme vás informovať, že %s zverejnil kalendár %s.",
    "Click on the link below to access it" : "Pre zobrazenie kliknite na odkaz nižšie",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "Today" : "Dnes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektoré udalosti v tomto kalendári sú poškodené. Pre viac informácií skontrolujte prosím JS konzolu.",
    "Share Calendar" : "Sprístupniť kalendár",
    "Shared" : "Sprístupnené",
    "More" : "Viac",
    "Edit" : "Upraviť",
    "Link" : "Odkaz",
    "iCal link" : "iCal odkaz",
    "Download" : "Sťahovanie",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "can edit" : "môže upraviť",
    "Share link" : "Sprístupniť odkaz",
    "Public access" : "Verejný prístup",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "New Calendar" : "Nový kalendár",
    "Name" : "Názov",
    "New Subscription" : "Nový odber",
    "Go back" : "Ísť späť",
    "Go forward" : "Ísť dopredu",
    "Edit event" : "Upraviť udalosť",
    "Delete Event" : "Zmazať udalosť",
    "Save Event" : "Uložiť udalosť",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relatívny",
    "Absolute" : "Absolútny",
    "Repeat" : "Opakovať",
    "times every" : "krát každý",
    "Add" : "Pridať",
    "E-Mail address of attendee" : "E-mail adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Pre pridávanie účastníkov priraďte k vašemu účtu e-mailovú adresu v osobných nastaveniach.",
    "from" : "od",
    "to" : "do",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pre rozšírené pravidlá bude pridaná v ďalších aktualizáciách.",
    "Reset repeating rule" : "Vypnúť pravidlo opakovania",
    "Repeat every ..." : "Opakovať každý ...",
    "end repeat ..." : "ukončiť opakovanie ...",
    "times" : "krát",
    "Import Calendars" : "Importovať kalendáre",
    "Import canceled" : "Import zrušený",
    "Analyzing calendar" : "Analyzujem kalendár",
    "The file contains objects incompatible with the selected calendar" : "Súbor obsahuje objekty, ktore nie sú kompatibilné so zvoleným kalendárom",
    "New calendar" : "Nový kalendár",
    "File is empty" : "Súbor je prázdny",
    "Import scheduled" : "Import naplánovaný",
    "Publish URL" : "Zverejniť URL",
    "Settings & import" : "Nastavenia a import",
    "Skip simple event editor" : "Nepoužívať jednoduchý editor",
    "Show week numbers" : "Zobraziť čísla týždňov",
    "Import calendar" : "Importovať kalendár",
    "No Calendars selected for import" : "Nebol označený kalendár na import",
    "Primary CalDAV address" : "Primárna CalDAV adresa",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
